@@ -1,6 +1,3 @@
-from enum import Enum
-
-
-class Metadata(str, Enum):
+class Metadata:
     IP_ADDRESS: str = "x-forwarded-for"
     USER_AGENT: str = "x-user-agent"
